from distutils.core import setup

setup(
        name = 'JIS_Nester',
        version = '1.0.0',
        py_modules = ['JIS_Nester'],
        author = 'jis',
        author_email = 'abc@gmail.com',
        url = 'http://www.google.com',
        description = 'A simple printer of nested lists',
        )

        
        
